@@ -2,9 +2,8 @@
  * Copyright (c) 2023 ipyforcegraph contributors.
  * Distributed under the terms of the Modified BSD License.
  */
-import { unpack_models as deserialize } from '@jupyter-widgets/base';
-
 import { IBehave, ILinkBehaveOptions } from '../../tokens';
+import { widget_serialization } from '../serializers/widget';
 
 import { FacetedModel } from './base';
 
@@ -13,10 +12,10 @@ export class LinkParticleModel extends FacetedModel implements IBehave {
 
   static serializers = {
     ...FacetedModel.serializers,
-    color: { deserialize },
-    density: { deserialize },
-    speed: { deserialize },
-    width: { deserialize },
+    color: widget_serialization,
+    density: widget_serialization,
+    speed: widget_serialization,
+    width: widget_serialization,
   };
 
   protected get _modelClass(): typeof LinkParticleModel {
