@@ -52,7 +52,11 @@ def atest(attempt, extra_args):
         *["--log", out_dir / "log.html"],
         *["--report", out_dir / "report.html"],
         *["--xunit", out_dir / "xunit.xml"],
+        *["--settag", f"ipfg:{P.PY_VERSION}"],
+        *["--settag", f"py:{P.PY_MAJOR}"],
+        *["--settag", f"os:{P.PLATFORM.lower()}"],
         *["--variable", f"OS:{P.PLATFORM}"],
+        *["--variable", f"PY:{P.PY_MAJOR}"],
         *["--variable", f"IPYFORCEGRAPH_EXAMPLES:{P.EXAMPLES}"],
         *["--variable", f"IPYFORCEGRAPH_FIXTURES:{P.ATEST_FIXTURES}"],
         *["--variable", f"""JUPYTERLAB_EXE:{" ".join(map(str, P.JUPYTERLAB_EXE))}"""],
