@@ -27,6 +27,7 @@ RE_PYTEST_TIMESTAMP = r"on \d{2}-[^\-]+-\d{4} at \d{2}:\d{2}:\d{2}"
 
 PATTERNS = [RE_TIMESTAMP, RE_PYTEST_TIMESTAMP]
 XP_JUPYTER_STDERR = """//*[@data-mime-type="application/vnd.jupyter.stderr"]"""
+XP_BAD_XREF = """//code[contains(@class, "xref")][not(parent::a)]"""
 
 
 def strip_timestamps(*paths, slug="TIMESTAMP"):
@@ -132,6 +133,12 @@ def notebook_lint(ipynb: Path):
         return False
 
 
+def fix_line_endings(filepath: Path):
+    """Convert any CRLF line endings to LF."""
+    print(f"... fixing line endings for {filepath.stem}")
+    filepath.write_bytes(filepath.read_bytes().replace(b"\r\n", b"\n"))
+
+
 def fix_windows_line_endings(max_chunk_size: int = 8000):
     """Break filelist into chunks for dos2unix call that converts CRLF to LF."""
     num_files = len(P.ALL_DOS2UNIX)
@@ -243,7 +250,7 @@ def lock_one(platform: str, lockfile: Path, stack: Paths) -> None:
 
     lock_args = ["conda-lock", "--kind=explicit"]
     comment = lock_comment(stack)
-    for env_file in reversed(stack):
+    for env_file in stack:
         lock_args += ["--file", env_file]
     lock_args += ["--platform", platform]
 
@@ -288,19 +295,17 @@ def sort_unique(path: Path):
         print(f"sorted and deduplicated {path}")
 
 
-def html_expect_xpath_matches(
-    html: Path, xpath: Optional[str] = XP_JUPYTER_STDERR, expected: Optional[int] = 0
-):
+def html_expect_xpath_matches(html: Path, xpath: str, expected: int, label: str):
     import lxml.html
 
-    tree = lxml.html.fromstring(html.read_text(**P.UTF8))
-    stderrs = tree.xpath(xpath)
+    tree = lxml.html.fromstring(html.read_bytes())
+    matches = tree.xpath(xpath)
+    if matches:
+        print(f"{html} contains {label}:")
+        for match in matches:
+            print(match.text_content(), "\n")
 
-    for stderr in stderrs:
-        print(f"{html} contains stderr:")
-        print(stderr.text_content(), "\n")
-
-    assert len(stderrs) == expected
+    return len(matches) == expected
 
 
 def clean_some(*paths: Path):
