@@ -2,9 +2,11 @@
 # Distributed under the terms of the Modified BSD License.
 
 import json
+from typing import Any, Dict, Optional
 
 import ipywidgets as W
 import numcodecs as N
+import numpy as np
 import pandas as P
 import traitlets as T
 
@@ -17,14 +19,16 @@ except ImportError:
     pass
 
 
-def dataframe_to_json(value: P.DataFrame, widget: W.Widget):
+def dataframe_to_json(
+    value: P.DataFrame, widget: W.Widget
+) -> Optional[Dict[str, memoryview]]:
     """DataFrame JSON serializer."""
     if value is None:
         return None
     if value is T.Undefined:
         raise T.TraitError("Cannot serialize undefined dataframe!")
 
-    df_data = value.to_dict(orient="list")
+    df_data = value.replace({np.nan: None}).to_dict(orient="list")
 
     if HAS_ORJSON:
         df_json = orjson.dumps(df_data)
@@ -34,19 +38,25 @@ def dataframe_to_json(value: P.DataFrame, widget: W.Widget):
     return {"buffer": memoryview(N.zstd.compress(df_json))}
 
 
-def dataframe_from_json(value: P.DataFrame, widget: W.Widget):
+def dataframe_from_json(value: Dict[str, Any], widget: W.Widget) -> P.DataFrame:
     """DataFrame JSON de-serializer."""
     if value is None:
         return None
 
-    if HAS_ORJSON:
-        df_data = orjson.loads(value)
+    if "buffer" in value:
+        decompressed = N.zstd.decompress(value["buffer"])
+
+        if HAS_ORJSON:
+            df_data = orjson.loads(decompressed.decode("utf-8"))
+        else:
+            df_data = json.loads(decompressed)
     else:
-        df_data = json.loads(df_data)
+        df_data = value
 
-    df_json = json.loads(N.zstd.decompress(value["buffer"]))
-
-    return P.DataFrame(df_json)
+    return P.DataFrame(df_data)
 
 
-dataframe_serialization = dict(to_json=dataframe_to_json, from_json=dataframe_from_json)
+dataframe_serialization = dict(
+    to_json=dataframe_to_json,
+    from_json=dataframe_from_json,
+)
